@@ -53,7 +53,9 @@ class Storage(driver.Base):
         path1 = self._init_path(path)
         output = StringIO.StringIO()
         try:
+            logger.info("get_content ------------------>path1:%s" % path1)
             object_instance = self._jss.bucket(self._bucket).object(path1)
+            logger.info("get_content object_instance:%s" % object_instance)
             res = object_instance.download_flow()
             logger.info("get_content res:%s" % res)
             while True:
